==> cloudt-system-api-0.2.9.1-20240422.034614-1-sources.jar: com/elitescloud/cloudt/system/provider/extend/SysAreaRpcService.java <==
package com.elitescloud.cloudt.system.provider.extend;

import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.system.dto.req.SysAreaNamesQueryDTO;
import com.elitescloud.cloudt.system.dto.req.SysAreaQueryDTO;
import com.elitescloud.cloudt.system.dto.resp.SysAreaNamesRespDTO;
import com.elitescloud.cloudt.system.dto.resp.SysAreaRespDTO;
import com.elitesland.cbpl.unicom.annotation.Unicom;
import com.elitesland.cbpl.unicom.domain.InvokeDomain;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Set;

/**
 * 行政区域服务接口.
 *
 * @author Kaiser（wang shao）
 * @date 3/3/2023
 */
@Validated
@Unicom(domain = InvokeDomain.SYSTEM, path = SysAreaRpcService.URI)
public interface SysAreaRpcService {
    String URI = Application.URI_PREFIX + "/area";

    /**
     * 根据编号查询行政区域
     *
     * @param areaCodes 行政区域编码
     * @return 行政区域列表
     */
    @PostMapping(value = "/listByAreaCodes")
    ApiResult<List<SysAreaRespDTO>> listByAreaCodes(@RequestBody @NotEmpty(message = "行政区域编码为空") Set<String> areaCodes);

    /**
     * 根据上级行政区域编码查询行政区域
     *
     * @param areaCode 上级行政区域编码
     * @return 行政区域列表
     */
    @GetMapping(value = "/listByParentAreaCode")
    ApiResult<List<SysAreaRespDTO>> listByParentAreaCode(@NotBlank(message = "上级行政区域编码为空") @RequestParam(value = "areaCode") String areaCode);

    /**
     * 查询行政区域
     *
     * @param queryDTO 查询参数
     * @return 行政区域列表
     */
    @PostMapping(value = "/queryList")
    ApiResult<List<SysAreaRespDTO>> queryList(@RequestBody SysAreaQueryDTO queryDTO);

    /**
     * 根据编码或名称组查询
     * <p>
     * 通常用于导入时，根据用户输入的编码或名称匹配行政区域编码，入参{@link SysAreaNamesQueryDTO#codeOrNames} 形如：
     * <pre>
     *     [
     *          ["北京", "北京市"],
     *          ["河南", "410300", "新安县"]
     *     ]
     * </pre>
     * 解析对应的行政区域编码，反参：
     * <pre>
     *     [
     *          {
     *              "codes": ["110000", "110100"],
     *              "names": ["北京市", "北京市"],
     *              "param": ["北京市", "北京市"]
     *          },
     *          {
     *              "codes": ["400000", "410300", "410323"],
     *              "names": ["河南", "洛阳市", "新安县"],
     *              "param": ["河南", "410300", "新安县"]
     *          }
     *     ]
     * </pre>
     * @param queryDTO 查询参数
     * @return 对象列表
     */
    @PostMapping(value = "/queryListByNames")
    ApiResult<List<SysAreaNamesRespDTO>> queryListByNames(@RequestBody SysAreaNamesQueryDTO queryDTO);
}

==> cloudt-system-api-3.0.15.0.6-20230303.084838-1-sources.jar: com/elitescloud/cloudt/system/provider/extend/SysAreaRpcService.java <==
package com.elitescloud.cloudt.system.provider.extend;

import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.system.dto.req.SysAreaQueryDTO;
import com.elitescloud.cloudt.system.dto.resp.SysAreaRespDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Set;

/**
 * 行政区域服务接口.
 *
 * @author Kaiser（wang shao）
 * @date 3/3/2023
 */
@FeignClient(name = Application.NAME, path = SysAreaRpcService.URI)
@Validated
public interface SysAreaRpcService {
    String URI = Application.URI_PREFIX + "/area";

    /**
     * 根据编号查询行政区域
     *
     * @param areaCodes 行政区域编码
     * @return 行政区域列表
     */
    @PostMapping(value = "/listByAreaCodes")
    ApiResult<List<SysAreaRespDTO>> listByAreaCodes(@RequestBody @NotEmpty(message = "行政区域编码为空") Set<String> areaCodes);

    /**
     * 根据上级行政区域编码查询行政区域
     *
     * @param areaCode 上级行政区域编码
     * @return 行政区域列表
     */
    @GetMapping(value = "/listByParentAreaCode")
    ApiResult<List<SysAreaRespDTO>> listByParentAreaCode(@NotBlank(message = "上级行政区域编码为空") @RequestParam(value = "areaCode") String areaCode);

    /**
     * 查询行政区域
     *
     * @param queryDTO 查询参数
     * @return 行政区域列表
     */
    @PostMapping(value = "/queryList")
    ApiResult<List<SysAreaRespDTO>> queryList(@RequestBody SysAreaQueryDTO queryDTO);
}
